package cc.fascinated.bat.common;

import lombok.experimental.UtilityClass;

import java.time.Instant;
import java.time.ZoneId;
import java.time.format.DateTimeFormatter;
import java.util.Date;
import java.util.Locale;

@UtilityClass
public class DateUtils {
    private static final ZoneId ZONE_ID = ZoneId.of("Europe/London");
    private static final DateTimeFormatter FORMATTER = DateTimeFormatter.ISO_INSTANT;
    private static final DateTimeFormatter SIMPLE_FORMATTER = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss z")
            .withLocale(Locale.UK)
            .withZone(ZONE_ID);

    /**
     * Gets the date from a string.
     *
     * @param date The date string.
     * @return The date.
     */
    public static Date getDateFromString(String date) {
        return Date.from(Instant.from(FORMATTER.parse(date)));
    }

    /**
     * Formats a date to a string.
     *
     * @param date The date to format.
     * @return The formatted date.
     */
    public String formatDate(Date date) {
        return SIMPLE_FORMATTER.format(date.toInstant());
    }
}
